==> 3.5.12-core.tar: kdegraphics/kolourpaint/widgets/kpcolorsimilaritycube.h <==

/*
   Copyright (c) 2003,2004,2005 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef __kp_color_similarity_cube_h__
#define __kp_color_similarity_cube_h__

#include <tqframe.h>

class kpColor;
class kpMainWindow;

class kpColorSimilarityCube : public QFrame
{
public:
    enum Look
    {
        Plain = 0,
        Depressed = 1,
        DoubleClickInstructions = 2
    };

    kpColorSimilarityCube (int look,
                           kpMainWindow *mainWindow,
                           TQWidget *parent,
                           const char *name = 0);
    virtual ~kpColorSimilarityCube ();

    static const double colorCubeDiagonalDistance;

    double colorSimilarity () const;
    void setColorSimilarity (double similarity);

    virtual TQSize sizeHint () const;

protected:
    TQColor color (int redOrGreenOrBlue, int baseBrightness, int similarityDirection) const;
    void drawFace (TQPainter *p,
                   int redOrGreenOrBlue,
                   const TQPoint &tl, const TQPoint &tr,
                   const TQPoint &bl, const TQPoint &br);
    virtual void drawContents (TQPainter *p);

    kpMainWindow *m_mainWindow;
    double m_colorSimilarity;
};

#endif  // __kp_color_similarity_cube_h__

==> 3.5.13-core.tar: kdegraphics/kolourpaint/widgets/kpcolorsimilaritycube.h <==

/*
   Copyright (c) 2003,2004,2005 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef __kp_color_similarity_cube_h__
#define __kp_color_similarity_cube_h__

#include <tqframe.h>

class kpColor;
class kpMainWindow;

class kpColorSimilarityCube : public TQFrame
{
public:
    enum Look
    {
        Plain = 0,
        Depressed = 1,
        DoubleClickInstructions = 2
    };

    kpColorSimilarityCube (int look,
                           kpMainWindow *mainWindow,
                           TQWidget *parent,
                           const char *name = 0);
    virtual ~kpColorSimilarityCube ();

    static const double colorCubeDiagonalDistance;

    double colorSimilarity () const;
    void setColorSimilarity (double similarity);

    virtual TQSize tqsizeHint () const;

protected:
    TQColor color (int redOrGreenOrBlue, int baseBrightness, int similarityDirection) const;
    void drawFace (TQPainter *p,
                   int redOrGreenOrBlue,
                   const TQPoint &tl, const TQPoint &tr,
                   const TQPoint &bl, const TQPoint &br);
    virtual void drawContents (TQPainter *p);

    kpMainWindow *m_mainWindow;
    double m_colorSimilarity;
};

#endif  // __kp_color_similarity_cube_h__
